import pytest

import mopidy_funkwhale.client

FUNKWHALE_URL = 'https://test.funkwhale'
FUNKWHALE_API_URL = FUNKWHALE_URL + '/api/v1/'


@pytest.fixture()
def session():
    return mopidy_funkwhale.client.get_requests_session(
        FUNKWHALE_URL,
        {},
        'test/something'
    )


@pytest.fixture()
def client(session):
    return mopidy_funkwhale.client.APIClient(session)


def test_client_search(client, requests_mock):
    requests_mock.get(FUNKWHALE_API_URL + 'search?query=myquery', json={'hello': 'world'})

    result = client.search('myquery')
    assert result == {'hello': 'world'}


def test_client_get_track(client, requests_mock):
    requests_mock.get(FUNKWHALE_API_URL + 'tracks/12/', json={'hello': 'world'})

    result = client.get_track(12)
    assert result == {'hello': 'world'}



def test_client_list_tracks(client, requests_mock):
    requests_mock.get(FUNKWHALE_API_URL + 'tracks/?artist=12', json={'hello': 'world'})

    result = client.list_tracks({'artist': 12})
    assert result == {'hello': 'world'}
